pub enum PickerMode {
Document,
Media,
Image,
Video,
}Expand description
The preferred mode of the file picker on mobile platforms (iOS and Android), which have distinct file and media pickers. On desktop, this option is ignored.
Variants
Document
Show the generic document picker.
Media
Show the media picker, allowing both images and videos to be selected.
Image
Show the media picker restricted to images.
Video
Show the media picker restricted to videos.